@@ -7,7 +7,7 @@ use MooX::BuildRole;
 use Constructor::SugarLibrary ();
 use Throwable::SugarFactory::Utils '_getglob';
 
-our $VERSION = '0.152690'; # VERSION
+our $VERSION = '0.152700'; # VERSION
 
 # ABSTRACT: build a library of syntax-sugared Moo classes
 
@@ -27,7 +27,7 @@ our $VERSION = '0.152690'; # VERSION
 
 sub import {
     my ( $class ) = @_;
-    Constructor::SugarLibrary->import::into( 1 );
+    Constructor::SugarLibrary->import::into( scalar caller );    # I::I 1.001000
     my $factory = caller;
     *{ _getglob $factory, $_ } = $class->_creator_with( $factory, $_ )
       for qw( class role );
@@ -58,7 +58,7 @@ MooX::SugarFactory - build a library of syntax-sugared Moo classes
 
 =head1 VERSION
 
-version 0.152690
+version 0.152700
 
 =head1 SYNOPSIS
 
