@@ -6,7 +6,7 @@ use MooX::SugarFactory ();
 use Throwable::SugarFactory::Utils '_getglob';
 use Throwable ();
 
-our $VERSION = '0.152690'; # VERSION
+our $VERSION = '0.152700'; # VERSION
 
 # ABSTRACT: build a library of syntax-sugared Throwable-based exceptions
 
@@ -35,7 +35,7 @@ sub _base_args {
 }
 
 sub import {
-    MooX::SugarFactory->import::into( 1 );
+    MooX::SugarFactory->import::into( scalar caller );    # I::I 1.001000 syntax
     my $factory = caller;
     *{ _getglob $factory, "exception" } = sub {
         my ( $id, $description, @args ) = @_;
@@ -58,7 +58,7 @@ Throwable::SugarFactory - build a library of syntax-sugared Throwable-based exce
 
 =head1 VERSION
 
-version 0.152690
+version 0.152700
 
 =head1 SYNOPSIS
 
